#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: ocr.py
# Mail: 1957875073@qq.com
# Created Time:  2022-4-25 10:17:34
# Description: 有关 ocr 的自动化操作
#############################################

"""
🌈5讲OCR批量识别（Python版）
https://www.python-office.com/course-002/5-poocr/5-poocr.html
"""